#
# spec file for package sddm
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_rundir: %global _rundir /run}
%{!?_unitdir: %global _unitdir /usr/lib/systemd/system}

Name:           sddm
Version:        0.13.0
Release:        9.15
Summary:        Lightweight QML-based display manager
License:        GPL-2.0+
Group:          System/GUI/KDE
Url:            https://github.com/sddm/sddm
Source:         https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        %{name}.conf
Source2:        X11-displaymanagers-%{name}
# default.face.icon.png and root.face.icon.png were part of Patch7 (0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch), but used as sources since binary patches are not supported
Source3:        default.face.icon.png
Source4:        root.face.icon.png
# PATCH-FIX-OPENSUSE proper_pam.diff -- Use openSUSE pam config
Patch0:         proper_pam.diff
# PATCH-FIX-OPENSUSE create_pid_file.patch -- openSUSE's generic display-manager service doesn't know what to do without a pid file. drop the patch as soon as that sick dinosaur is killed
Patch1:         create_pid_file.patch
# PATCH-FIX-OPENSUSE sddm-relaxed-auth.diff -- Insert XAUTHLOCALHOSTNAME into users enviroment, so the session handles hostname changes with a single X instance/run
# related patches: libxcb/bug-262309_xcb-xauthlocalhostname.diff, xauth/xauth-tolerant-hostname-changes.diff, kdebase4-workspace/kdm-relaxed-auth.diff
Patch2:         sddm-relaxed-auth.diff
# PATCH-FIX-OPENSUSE sysconfig-support.patch -- Support DISPLAYMANAGER_AUTOLOGIN entry from /etc/sysconfig/displaymanager, the value overwrites
# any entry in sddm.conf/[Autologin]/User. Patch also defaults to plasma5.desktop as default autologin session. This is controlled only by sddm.conf file.
Patch3:         sysconfig-support.patch
# PATCH-FIX-OPENSUSE sddm-service-handle-plymouth.patch -- sddm has some rudimentary support for plymouth handling, which only works with plymouth-quit.service
# (the servce is not enabled on openSUSE). For users of sddm.service, we need to issue plymouth quit command by hand in this case
Patch4:         sddm-service-handle-plymouth.patch
# PATCH-FIX-OPENSUSE boo949903.patch -- Let sddm also default to plasma5 for last used session (boo#949903)
Patch5:         boo949903.patch
# PATCH-FIX-UPSTREAM 0001-Add-a-config-option-to-enable-avatars.patch -- Add EnableAvatars config option
Patch6:         0001-Add-a-config-option-to-enable-avatars.patch
# PATCH-FIX-UPSTREAM 0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch -- Use new face icons
Patch7:         0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch
# PATCH-FIX-UPSTREAM add-count-property-to-UserModel.patch -- Adds a new property so themes can use it
Patch8:         add-count-property-to-UserModel.patch
# PATCH-FIX-UPSTREAM specify-default-config-entries.patch -- Specify which config entries are a default and which come from the config file
Patch9:         specify-default-config-entries.patch
# PATCH-FIX-UPSTREAM add-threshold-to-disable-avatars.patch -- Add a config option/property to define a thershold above which avatars are disabled automatically
Patch10:        add-threshold-to-disable-avatars.patch
# PATCH-FIX-UPSTREAM 0001-Make-the-default-cursor-themed.patch -- Make the default cursor themed
Patch11:        0001-Make-the-default-cursor-themed.patch
# PATCH-FIX-UPSTREAM 0001-Fall-back-to-regular-login-when-autologin-fails.patch -- Fall back to regular login when autologin fails
Patch12:        0001-Fall-back-to-regular-login-when-autologin-fails.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pam-devel
BuildRequires:  pkg-config
BuildRequires:  python-docutils
# Autodetect UID_MIN and UID_MAX from /etc/login.defs
BuildRequires:  shadow
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(xcb-xkb)
Requires:       sddm-branding = %{version}
# Merged the -lang package back into the main package
Provides:       %{name}-lang = %{version}
Obsoletes:      %{name}-lang < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SDDM is a modern display manager for X11 aiming to be fast, simple and beatiful.
It uses modern technologies like QtQuick, which in turn gives the designer the
ability to create smooth, animated user interfaces.

%package branding-openSUSE
Summary:        Lightweight QML-based display manager. openSUSE branding
Group:          System/GUI/KDE
PreReq:         sddm
Requires:       sddm-theme-openSUSE
Supplements:    packageand(plasma5-workspace:branding-openSUSE)
Provides:       sddm-branding = %{version}
Conflicts:      otherproviders(sddm-branding)

%description branding-openSUSE
SDDM is a modern display manager for X11 aiming to be fast, simple and beatiful.
It uses modern technologies like QtQuick, which in turn gives the designer the
ability to create smooth, animated user interfaces. This package provides
openSUSE branding for SDDM.

%package branding-upstream
Summary:        Lightweight QML-based display manager. upstream branding
Group:          System/GUI/KDE
Supplements:    packageand(plasma5-workspace:branding-upstream)
Provides:       sddm-branding = %{version}
Conflicts:      otherproviders(sddm-branding)

%description branding-upstream
SDDM is a modern display manager for X11 aiming to be fast, simple and beatiful.
It uses modern technologies like QtQuick, which in turn gives the designer the
ability to create smooth, animated user interfaces. This package provides
upstream branding for SDDM.

%prep
%setup -q -n %{name}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
cp %{SOURCE3} data/faces/default.face.icon.png
cp %{SOURCE4} data/faces/root.face.icon.png

%build
%cmake \
      -DCMAKE_BUILD_TYPE=Release \
      -DMINIMUM_VT=7 \
      -DCMAKE_INSTALL_LIBEXECDIR=%{_libexecdir}/%{name} \
      -DIMPORTS_INSTALL_DIR="%{_libdir}/qt5/qml" \
      -DSESSION_COMMAND="/etc/X11/xdm/Xsession" \
      -DBUILD_MAN_PAGES=ON \
      -DSTATE_DIR="/var/lib/sddm" \
      -DRUNTIME_DIR="/run/sddm" \
      -DPID_FILE="/run/sddm.pid"
  %make_jobs

%install
  %kf5_makeinstall -C build

  pushd %{buildroot}%{_sysconfdir}/dbus-1/system.d
  mv org.freedesktop.DisplayManager.conf sddm_org.freedesktop.DisplayManager.conf
  popd

  install -Dm 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}.conf
  install -Dm 0644 %{SOURCE2} %{buildroot}%{_libexecdir}/X11/displaymanagers/%{name}
  install -d %{buildroot}%{_rundir}/sddm
  install -d %{buildroot}%{_localstatedir}/lib/sddm

  %fdupes -s %{buildroot}%{_datadir}/sddm

%pre
/usr/sbin/groupadd -r sddm 2> /dev/null || :
/usr/sbin/useradd -r -g sddm -s /bin/false -c "SDDM daemon" \
    -d /var/lib/sddm sddm 2> /dev/null || :

%post branding-openSUSE
if [ $1 -ge 1 -a -f /etc/sddm.conf ]; then
    # Upgrade from previous theme name
    sed -i -e 's/^Current=breeze$/Current=breeze-openSUSE/g' /etc/sddm.conf
    sed -i -e 's/^Current=maui$/Current=breeze-openSUSE/g' /etc/sddm.conf
fi

%postun branding-openSUSE
if [ $1 -eq 0 -a -f /etc/sddm.conf ]; then
   sed -i -e 's/^Current=breeze-openSUSE$/Current=maui/g' /etc/sddm.conf
fi

%files
%defattr(-,root,root)
%doc COPYING* README*
%config(noreplace) %{_sysconfdir}/%{name}.conf
%config %{_sysconfdir}/pam.d/sddm
%config %{_sysconfdir}/pam.d/sddm-autologin
%config %{_sysconfdir}/pam.d/sddm-greeter
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/sddm_org.freedesktop.DisplayManager.conf
%{_sysconfdir}/pam.d/sddm*
%{_libexecdir}/sddm/
%dir %{_libexecdir}/X11/displaymanagers/
%{_libexecdir}/X11/displaymanagers/%{name}
%{_bindir}/sddm
%{_bindir}/sddm-greeter
%{_libdir}/qt5/qml/
%dir %{_datadir}/sddm/
%{_datadir}/sddm/faces/
%{_datadir}/sddm/flags/
%{_datadir}/sddm/scripts/
%{_datadir}/sddm/themes/
%{_datadir}/sddm/translations/
%{_mandir}/man*/sddm*.*
%ghost %attr(711,sddm,sddm) %dir %{_rundir}/sddm
%attr(750,sddm,sddm) %dir %{_localstatedir}/lib/sddm
%{_unitdir}/sddm.service

%files branding-openSUSE
%defattr(-,root,root)
%doc COPYING* README*

%files branding-upstream
%defattr(-,root,root)
%doc COPYING* README*

%changelog
* Sat Sep 24 2016 fabian@ritter-vogt.de
- Add 0001-Fall-back-to-regular-login-when-autologin-fails.patch
  to fix crash when autologin session not found (boo#1000917)
* Thu Sep 22 2016 fabian@ritter-vogt.de
- Add 0001-Make-the-default-cursor-themed.patch to fix the default
  cursor appearance
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Provide sddm-lang
* Thu Sep 15 2016 alarrosa@suse.com
- Use the new theme name, breeze-openSUSE, in sddm-branding-openSUSE
- Require the new sddm-theme-openSUSE package
* Wed Jun  8 2016 fbui@suse.com
- Fix build requirements on systemd (bsc#983167)
  Use pkgconfig() so we don't need to rely on package names. For the
  record, systemd.pc is now part of systemd main package.
* Fri Nov 20 2015 alarrosa@suse.com
- Renamed config option and property from UsersThresholdToDisableAvatars
  to DisableAvatarsThreshold as proposed by upstream before accepting
  the patches.
* Wed Nov 11 2015 alarrosa@suse.com
- Add patch add-count-property-to-UserModel.patch: Adds a property so
  sddm themes can access the number of users in the system
- Add patch specify-default-config-entries.patch: Stores which config
  values have been read from the config file or are just default values.
- Add patch add-threshold-to-disable-avatars.patch: Adds a config option
  and property named UsersThresholdToDisableAvatars, if the number of
  users in the system is greater than the threshold, use a default avatar
  for all users and disable avatar loading.
- These patches together with patches in plasma5-workspace fix bnc#953778
* Fri Nov  6 2015 alarrosa@suse.com
- Update to 0.13.0:
  * Greeter inherits path environment variables from parent so that
    themes installed in non-standard paths will work.
  * Add ENABLE_PAM option to toggle PAM support at build time.
  * Allow overriding textColor in ComboBox.
  * Don't cast QByteArray to (char *).
  * Disable greeters from loading KDE's debug hander
    (fix CVE-2015-0856).
  * Fix multi-screen support for some setups.
  * Added Serbian translation.
  * Added Traditional Chinese translation.
  * Improved German translation.
  * Remove failsafe session entry.
  * Close the pipe fd passed to X server.
  * A few micro-optimizations.
- Removed patches already in this version:
    0001-always-create-window-for-each-screen.patch
    0002-screen-model-for-each-window.patch
    0001-Don-t-cast-QByteArray-to-char.patch
    0002-Disable-greeters-from-loading-KDE-s-debug-hander.patch
- Updated patches to apply cleanly:
    boo949903.patch
    sddm-relaxed-auth.diff
    sysconfig-support.patch
- Added patches from upstream to add a config option that can be
  used to disable the loading of user avatars (EnableAvatars):
    0001-Add-a-config-option-to-enable-avatars.patch
    0002-Use-.face.icon-instead-of-default.face.icon-and-rena.patch
* Sat Oct 24 2015 tchvatal@suse.com
- Add upstream patches to fix multihead in some cases
  (also fixes boo#950293):
  * 0001-always-create-window-for-each-screen.patch
  * 0002-screen-model-for-each-window.patch
* Sun Oct 18 2015 hrvoje.senjan@gmail.com
- openSUSE branding now needs to require plasma5-workspace-branding
* Thu Oct 15 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Don-t-cast-QByteArray-to-char.patch
  (https://github.com/sddm/sddm/issues/489)
  and 0002-Disable-greeters-from-loading-KDE-s-debug-hander.patch
  (boo#950491, CVE-2015-0856)
* Sun Oct 11 2015 hrvoje.senjan@gmail.com
- Added boo949903.patch: Let sddm also default to plasma5 for last
  used session (boo#949903)
* Thu Sep 24 2015 hrvoje.senjan@gmail.com
- Added shadow BuildRequires, it's needed to check UID_MIN & UID_MAX
  from /etc/login.defs
* Sat Sep 12 2015 wbauer@tmo.at
- Change the theme to "maui" in the shipped sddm.conf,
  sddm-branding-openSUSE sets it to "breeze" on installation.
- Remove the superfluous requirement for "breeze". This is not
  needed even with the "breeze" theme, as it is actually part of
  plasma5-workspace which is required by sddm-branding-openSUSE
  anyway.
- sddm-branding-openSUSE should PreReq sddm, otherwise the config
  might not exist.
- Make the regexps for sed stricter to really only modify the theme
  setting when installing/uninstalling sddm-branding-openSUSE.
  Otherwise it would e.g. also replace CursorTheme=breeze_cursors
  with CursorTheme=maui_cursors...
  Also only modify the config on new installation, not during
  updates.
* Sun Sep  6 2015 hrvoje.senjan@gmail.com
- Update to 0.12.0:
  * SDDM now depends on Qt >= 5.3
  * Display setup script is now killed if it hasn't finished
    within 30 seconds.
  * The Maldives non-free background has been replaced by a
    CC-BY-SA alternative
  * Wayland sessions support
  * New sddm.conf option XephyrPath
    (defaults to /usr/bin/Xephyr)
  * new sddm.conf option ServerArguments
    (defaults to -nolisten tcp)
  * new sddm.config option DisplayStopCommand (executes Xstop)
  * Assorted improvements to the default theme
  * Honor TryExec in Xsession desktop files
  * Fix session startup on zsh
  * Allow setting a custom DBUS_CONFIG_FILENAME at compile time
  * Allow SYSTEMD_SYSTEM_UNIT_DIR to be overridden at compile time
  * Allow QT_IMPORTS_DIR to be overridden at compile time
  * No longer hardcode min/max UIDs, allow setting
    UID_MIN and UID_MAX at compile time
  * Assorted FreeBSD fixes
  * Fix build warnings with Qt 5.5.
  * Enable QT_NO_CAST_FROM_ASCII
  * Added Arabic
  * Added Hungarian
  * Various i18n updates and improvements
  * Full right-to-left languages support.
- Drop sddm-wait-for-display-script.patch, merged upstream
* Wed Aug 26 2015 herbert@graeber-clan.de
- Added patch from upstream sddm-wait-for-display-script.patch:
  avoid a black screen (boo#942815)
* Mon Jun  1 2015 dimstar@opensuse.org
- Do not split out a -lang package: the translations are not in
  standard locations and having the -lang package confuses
  bundle-lang-kde, which can't move the files to the bundle, thus
  resulting in conflicting packages.
* Mon May 25 2015 hrvoje.senjan@gmail.com
- Add sddm-service-handle-plymouth.patch -- sddm has some rudimentary
  support for plymouth handling, which only works with
  plymouth-quit.service (the servce is not enabled on openSUSE).
  For users of sddm.service, we need to issue plymouth quit command
  by hand in this case
* Mon May  4 2015 hrvoje.senjan@gmail.com
- Add sysconfig-support.patch: Support DISPLAYMANAGER_AUTOLOGIN
  entry from /etc/sysconfig/displaymanager, the value overwrites
  any entry in sddm.conf/[Autologin]/User. Patch also defaults
  to plasma5.desktop as default autologin and last selected
  sessions. This is controlled only by sddm.conf file.
- Mark sddm.conf as %%config(noreplace)
* Wed Apr 29 2015 hrvoje.senjan@gmail.com
- Added sddm-relaxed-auth.diff: Insert XAUTHLOCALHOSTNAME into
  users enviroment, so the session handles hostname changes with
  a single X instance/run
- Use breeze_cursors in openSUSE branding
* Mon Mar 16 2015 hrvoje.senjan@gmail.com
- Drop conflict with lightdm, and move DBus configuration file,
  now that sddm is whitelisted
- Drop xdm (Build)Requires
- Install sddm-pam* directly, instead of messing with symlinking
- Add create_pid_file.patch: openSUSE's generic display-manager
  service doesn't know what to do without a pid file. drop the patch
  as soon as that sick dinosaur is killed
- Drop ommit_systemd_service.patch
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Add conflict with lightdm due to same DBus configuration file
* Mon Dec  8 2014 hrvoje.senjan@gmail.com
- Update to 0.11.0
  * Reload the configuration every time we start a new session
  * Fix stderr redirection in the helper. Solving a memory leak
  * Set system locale in the greeter
  * Bail on chdir failure
  * Use QUuid for unique ID generation
  * Update lithuanian translations
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Create openSUSE and upstream branding packages, now only openSUSE
  branding depends on plasma5-workspace
* Fri Oct 17 2014 hrvoje.senjan@gmail.com
- Update to 0.10.0:
  * BACKWARDS INCOMPATIBLE: Drop support for Qt 4.
  * BACKWARDS INCOMPATIBLE: SDDM now prioritizes loading sessions
    with a .desktop prefix
  * SECURITY: Never try to login as the sddm user (CVE-2014-7271)
  * SECURITY: Fix race condition in XAUTHORITY file generation
    (CVE-2014-7272)
  * SECURITY: XAUTHORITY file is no longer owned by root
  * New translation: Kazakh
  * Fixed password field initial focus state
  * When the default theme is not available, sddm now loads the
    first theme in alphabetical order
  * Fixed PAM environment variables being overridden
  * Fixed autologin with the passwd backend
  * Greeter themes can now specify their own icon and
    cursor themes.
  * Various bugfixes with SessionCommand/XSession support
  * Various bugfixes with test mode.
  * Various cleanups
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 0.9.9~git20141009:
  * resolved CVE-2014-7272 and bnc#897788
  * Dropped support for Qt4
  * Flush any buffered data to the log file, this writes
    immediately all the log messages.
  * Don't override pam environment variables.
  * Set default icon theme from greeter theme configuration.
  * Set cursor theme according to greeter theme configuration.
- Drop 0001-Never-try-to-login-as-the-user-SDDM.patch,
  0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch
  and 0001-Don-t-override-pam-environment-variables.patch: merged
  upstream
* Mon Oct  6 2014 hrvoje.senjan@gmail.com
- Added 0001-Never-try-to-login-as-the-user-SDDM.patch and
  0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch to
  resolve bnc#897788 and CVE-2014-7272
- Leave 0001-Move-onAuthenticated-XAUTHORITY-generation-to-the-he.patch
  disabled for the moment, as it completely breaks users login
* Sun Sep 21 2014 hrvoje.senjan@gmail.com
- Make it build for 13.1: define /rundir if undefined
- 0001-Don-t-override-pam-environment-variables.patch: fixes
  https://github.com/sddm/sddm/issues/256
* Thu Aug 21 2014 hrvoje.senjan@gmail.com
- Update to 0.9.0
  * Several systemd, logind and journald improvements. Note that
    systemd is not required to run SDDM.
  * The SDDM greeter now runs as its own user and group, instead
    of root.
  * Support for setting the keyboard layout from the greeter.
  * An "AutoUser" config key to configure automatic login.
  * A "NumLock" config key to configure NumLock state at boot.
  * Overhauled configuration file handling.
  * SDDM runs with the default configuration without /etc/sddm.conf
  * Initial (albeit not fully functional) Plymouth support.
  * Translations in 11 languages.
  * Several licensing and packaging improvements.
  * Better documentation, including man pages for sddm(1),
    sddm-greeter(1), sddm.conf(5) and sddm-state.conf(5).
* Fri Aug 23 2013 hrvoje.senjan@gmail.com
- Update to latest snapshot
- Added pkgconfig(xcb-xkb) BuildRequires
- Dropped libupower-glib-devel BuildRequire
- Utilize systemd macros for sddm service
- Small spec cleanup
- Use sed instead of two patches
* Sun Mar 17 2013 hrvoje.senjan@gmail.com
- Initial packaging of sddm, Lightweight QML-based display manager
